==> haskell-brick-0.40-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.40
id: brick-0.40-JRR44n5xyEzJdQbgCOEsju
key: brick-0.40-JRR44n5xyEzJdQbgCOEsju
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: 629933d20c19228b90bfa7e44709994a
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.List Brick.Widgets.ProgressBar
    Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/brick-0.40
library-dirs: /usr/lib/ghc-8.4.3/site-local/brick-0.40
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/brick-0.40
hs-libraries: HSbrick-0.40-JRR44n5xyEzJdQbgCOEsju
depends:
    base-4.11.1.0 vty-5.23.1-4qkZoKfk0ow9l88VLm7tU3
    transformers-0.5.5.0 data-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD containers-0.5.11.0
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh
    microlens-th-0.4.2.2-CtKFRxCaH8TKvI1HPe9Q9y
    microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5
    config-ini-0.2.2.0-8OxmO5WFM0jBhdNta1VFPo
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA stm-2.4.5.0 text-1.2.3.0
    text-zipper-0.10.1-FKr757Ehlm781t7MIAycmD template-haskell-2.13.0.0
    deepseq-1.4.3.0 word-wrap-0.4.1-4dBPNVAFjeL6gCWTgE924g
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             vty-5.23.1-4qkZoKfk0ow9l88VLm7tU3=90d1b19de15b679b08195b31463f68aa
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             data-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V=85a7a260ba6507ed53ba49e7d137b01a
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=ea4e8465edaf940bc6b809afec7d8a0c
             microlens-th-0.4.2.2-CtKFRxCaH8TKvI1HPe9Q9y=57e31df6646ed91dcbc51d429799fca5
             microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5=1a8e1231c2e84cbd42a7eb5d31204255
             config-ini-0.2.2.0-8OxmO5WFM0jBhdNta1VFPo=d332ec1a9bc1fa02ba80225f75098e41
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             text-zipper-0.10.1-FKr757Ehlm781t7MIAycmD=543a12d3646a98ae0f6148477730f4c1
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             word-wrap-0.4.1-4dBPNVAFjeL6gCWTgE924g=4aa3023e5753058a6bec35e13e7da0fe
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.41-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.41
id: brick-0.41-InnqWcRo7H4GqLGSNpFnUa
key: brick-0.41-InnqWcRo7H4GqLGSNpFnUa
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: c42bfccbcec313a7968430270cc74172
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.List Brick.Widgets.ProgressBar
    Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/brick-0.41
library-dirs: /usr/lib/ghc-8.4.3/site-local/brick-0.41
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/brick-0.41
hs-libraries: HSbrick-0.41-InnqWcRo7H4GqLGSNpFnUa
depends:
    base-4.11.1.0 vty-5.24-JmD3l917sdAHcppZY5zmFQ transformers-0.5.5.0
    data-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD containers-0.5.11.0
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh
    microlens-th-0.4.2.2-CtKFRxCaH8TKvI1HPe9Q9y
    microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5
    config-ini-0.2.2.0-AMmAQ3Maapr2g2WVqMLq6d
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA stm-2.4.5.0 text-1.2.3.0
    text-zipper-0.10.1-FKr757Ehlm781t7MIAycmD template-haskell-2.13.0.0
    deepseq-1.4.3.0 word-wrap-0.4.1-HskzYLaRev69mq9wcxux6F
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             vty-5.24-JmD3l917sdAHcppZY5zmFQ=b6d99865a746ce0389dce6b63be66f1a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             data-clist-0.1.2.1-JQwK0J4X8cELKfb0PagR1V=85a7a260ba6507ed53ba49e7d137b01a
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=ea4e8465edaf940bc6b809afec7d8a0c
             microlens-th-0.4.2.2-CtKFRxCaH8TKvI1HPe9Q9y=57e31df6646ed91dcbc51d429799fca5
             microlens-mtl-0.1.11.1-KuiQwUtjPQq9JoX7IucQt5=1a8e1231c2e84cbd42a7eb5d31204255
             config-ini-0.2.2.0-AMmAQ3Maapr2g2WVqMLq6d=cb5776278d5bbc2c50b0fe597a704433
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             text-zipper-0.10.1-FKr757Ehlm781t7MIAycmD=543a12d3646a98ae0f6148477730f4c1
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             word-wrap-0.4.1-HskzYLaRev69mq9wcxux6F=da5850fdf1a029ee88886b1c155c6785
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
